from setuptools import setup

setup(
    name = "fzh_bigdata3",
    version = "2.0",
    py_modules = ["fzh_xd_bigdata"],
    author = "大数据1",
    author_email = "2011370989@qq.com",
    description = "风之花"
)